"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchBuiltinComponentStyle = void 0;
const mz_1 = require("mz");
const path_1 = require("path");
const isBuiltinComponent = (pkgName) => /^(@jd)\/.*/.test(pkgName);
// 根据组件 npm 包名以及通过 yarn 下载到磁盘上的 npm 包路径，读入对应的样式文件内容，并写入到 manifest.json 的 contents 对象上
const insertStyle = (contents, packageName, packagePath) => {
    const stylePath = `node_modules/${packageName}/dist/index.css`;
    const styleFilePath = path_1.join(packagePath, `node_modules/${packageName}/dist/index.css`);
    if (mz_1.fs.existsSync(styleFilePath)) {
        contents[stylePath] = {
            contents: mz_1.fs.readFileSync(styleFilePath, "utf-8"),
            isModule: false,
        };
    }
};
// 获取内建组件的样式文件，并写入到返回给 Sandbox 的 manifest.json 文件中
exports.fetchBuiltinComponentStyle = (contents, packageName, packagePath, dependencyDependencies) => {
    // 当 npm 包或者其依赖以及依赖的依赖中有内建组件，则将该内建组件对应的样式文件写入到 manifest.json 文件中
    if (isBuiltinComponent(packageName)) {
        insertStyle(contents, packageName, packagePath);
    }
    Object.keys(dependencyDependencies.dependencyDependencies).forEach((pkgName) => {
        if (isBuiltinComponent(pkgName)) {
            insertStyle(contents, pkgName, packagePath);
        }
    });
};
//# sourceMappingURL=fetch-builtin-component-style.js.map